@@ -4,7 +4,7 @@ import (
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/pkg/cmd/attestation/download"
 	"github.com/cli/cli/v2/pkg/cmd/attestation/inspect"
-	"github.com/cli/cli/v2/pkg/cmd/attestation/tufrootverify"
+	"github.com/cli/cli/v2/pkg/cmd/attestation/trustedroot"
 	"github.com/cli/cli/v2/pkg/cmd/attestation/verify"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 
@@ -17,8 +17,6 @@ func NewCmdAttestation(f *cmdutil.Factory) *cobra.Command {
 		Short:   "Work with artifact attestations",
 		Aliases: []string{"at"},
 		Long: heredoc.Doc(`
-			### NOTE: This feature is currently in beta, and subject to change.
-
 			Download and verify artifact attestations.
 			`),
 	}
@@ -26,7 +24,7 @@ func NewCmdAttestation(f *cmdutil.Factory) *cobra.Command {
 	root.AddCommand(download.NewDownloadCmd(f, nil))
 	root.AddCommand(inspect.NewInspectCmd(f, nil))
 	root.AddCommand(verify.NewVerifyCmd(f, nil))
-	root.AddCommand(tufrootverify.NewTUFRootVerifyCmd(f, nil))
+	root.AddCommand(trustedroot.NewTrustedRootCmd(f, nil))
 
 	return root
 }
