@@ -104,6 +104,11 @@ func TestNewCmdEdit(t *testing.T) {
 			},
 			wantsErr: false,
 		},
+		{
+			name:     "both body and body-file flags",
+			input:    "23 --body foo --body-file bar",
+			wantsErr: true,
+		},
 		{
 			name:  "add-assignee flag",
 			input: "23 --add-assignee monalisa,hubot",
@@ -206,6 +211,25 @@ func TestNewCmdEdit(t *testing.T) {
 			},
 			wantsErr: false,
 		},
+		{
+			name:  "remove-milestone flag",
+			input: "23 --remove-milestone",
+			output: EditOptions{
+				SelectorArgs: []string{"23"},
+				Editable: prShared.Editable{
+					Milestone: prShared.EditableString{
+						Value:  "",
+						Edited: true,
+					},
+				},
+			},
+			wantsErr: false,
+		},
+		{
+			name:     "both milestone and remove-milestone flags",
+			input:    "23 --milestone foo --remove-milestone",
+			wantsErr: true,
+		},
 		{
 			name:  "add label to multiple issues",
 			input: "23 34 --add-label bug",
@@ -221,17 +245,8 @@ func TestNewCmdEdit(t *testing.T) {
 			wantsErr: false,
 		},
 		{
-			name:  "interactive multiple issues",
-			input: "23 34",
-			output: EditOptions{
-				SelectorArgs: []string{"23", "34"},
-				Editable: prShared.Editable{
-					Labels: prShared.EditableSlice{
-						Add:    []string{"bug"},
-						Edited: true,
-					},
-				},
-			},
+			name:     "interactive multiple issues",
+			input:    "23 34",
 			wantsErr: true,
 		},
 	}
